import _assertThisInitialized from "@babel/runtime/helpers/esm/assertThisInitialized";
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import PropTypes from 'prop-types';
import React, { Component } from 'react';
import Button from '@s-ui/react-atom-button';
import Collapsible from '@schibstedspain/sui-collapsible-basic';
import IconX from '@s-ui/react-icons/lib/X';
import cx from 'classnames';

var CardCollapsible =
/*#__PURE__*/
function (_Component) {
  _inheritsLoose(CardCollapsible, _Component);

  function CardCollapsible(props) {
    var _this;

    _this = _Component.call(this, props) || this;
    _this.state = {
      collapsed: props.collapsed
    };
    _this._toggleCardContent = _this._toggleCardContent.bind(_assertThisInitialized(_this));
    return _this;
  }
  /**
   * Changes the collapsed/expand state of the card's content.
   */


  var _proto = CardCollapsible.prototype;

  _proto._toggleCardContent = function _toggleCardContent() {
    this.setState({
      collapsed: !this.state.collapsed
    });
  }
  /**
   * Renders a single text info item, that will be displayed in the card's header positioned depending on the expanded/collapsed state.
   * @param {Object} itemProps              Properties to include in text info item HTML Element.
   * @param {string} itemProps.label        Text to display.
   * @param {string} itemProps.link         If set, item will be displayed as a text link.
   * @param {boolean} itemProps.highlighted Highlight the item (bold style).
   * @return {Element} Item to display on card's header info area.
   */
  ;

  _proto._renderInfoItem = function _renderInfoItem(_ref, index) {
    var label = _ref.label,
        link = _ref.link,
        highlighted = _ref.highlighted,
        _ref$target = _ref.target,
        target = _ref$target === void 0 ? '_blank' : _ref$target,
        IconLeft = _ref.iconLeft,
        onClick = _ref.onClick;
    var InfoItemElement = link ? 'a' : 'span';
    var props = link ? {
      href: link,
      target: target,
      onClick: onClick
    } : {};
    return React.createElement(InfoItemElement, Object.assign({
      key: "header-info-item-" + index,
      className: cx('sui-CardCollapsible-headerInfoItem', {
        'sui-CardCollapsible-headerInfoItemLink': !!link,
        'is-highlighted': !!highlighted
      })
    }, props), IconLeft && React.createElement(IconLeft, {
      svgClass: "sui-CardCollapsible-infoItemIcon",
      className: "sui-CardCollapsible-infoItemIcon"
    }), React.createElement("span", null, label));
  };

  _proto._renderCardCloseButton = function _renderCardCloseButton() {
    var _this$props$iconClose = this.props.iconClose,
        Icon = _this$props$iconClose === void 0 ? IconX : _this$props$iconClose;
    return React.createElement("div", {
      className: "sui-CardCollapsible-headerClose"
    }, React.createElement("a", {
      className: "sui-CardCollapsible-closeButton",
      onClick: this._toggleCardContent
    }, React.createElement(Icon, {
      svgClass: "sui-CardCollapsible-closeIcon",
      className: "sui-CardCollapsible-closeIcon"
    })));
  }
  /**
   * Renders the card's header, which may be different depending on its collapsed state, and the configuration defined in prop "headerInfo".
   * @param {Object} headerImage Configuration of the image to display in card's header.
   * @param {string} [headerImage.alt=logo]
   * @param {string} headerImage.href
   * @param {string} headerImage.src
   * @param {string} [headerImage.target=_blank]
   * @param {Object[]} info List of item info labels to show in card's header.
   * @return {Element} Card' header element.
   */
  ;

  _proto._renderCardHeader = function _renderCardHeader(_ref2, info) {
    var _ref2$alt = _ref2.alt,
        alt = _ref2$alt === void 0 ? 'logo' : _ref2$alt,
        href = _ref2.href,
        src = _ref2.src,
        _ref2$target = _ref2.target,
        target = _ref2$target === void 0 ? '_blank' : _ref2$target;
    var collapsed = this.state.collapsed;
    var Image = React.createElement("img", {
      src: src,
      alt: alt
    });
    return React.createElement("div", {
      className: cx('sui-CardCollapsible-header', {
        'is-expanded': !collapsed
      })
    }, React.createElement("div", {
      className: "sui-CardCollapsible-headerImage"
    }, href ? React.createElement("a", {
      href: href,
      target: target
    }, Image) : Image), info && React.createElement("div", {
      className: "sui-CardCollapsible-headerInfo"
    }, info.map(this._renderInfoItem)));
  }
  /**
   * Renders the action button which trigger the expand/collapse action of the card.
   * @param config {object} Button configuration (prop "label" : Text label of expand/collapse action button).
   */
  ;

  _proto._renderExpandButton = function _renderExpandButton() {
    var _this$props$expandBut = this.props.expandButton;
    _this$props$expandBut = _this$props$expandBut === void 0 ? {} : _this$props$expandBut;
    var label = _this$props$expandBut.label;
    return !!label && React.createElement(Button, {
      fullWidth: true,
      size: "large",
      onClick: this._toggleCardContent
    }, label);
  };

  _proto.render = function render() {
    var collapsed = this.state.collapsed;
    var _this$props = this.props,
        className = _this$props.className,
        children = _this$props.children,
        headerImage = _this$props.headerImage,
        headerInfo = _this$props.headerInfo,
        onChangeHandler = _this$props.onChangeHandler,
        showCloseButton = _this$props.showCloseButton,
        hasBoxShadowWhenExpanded = _this$props.hasBoxShadowWhenExpanded;
    var headerInfoConfig = collapsed ? headerInfo.displayWhenCollapsed : headerInfo.displayWhenExpanded;
    var cssClassName = cx('sui-CardCollapsible', className, {
      'is-expanded': !collapsed,
      'sui-CardCollapsible--boxShadow': hasBoxShadowWhenExpanded
    });
    return React.createElement("div", {
      className: cssClassName
    }, !collapsed && showCloseButton && this._renderCardCloseButton(), headerInfo && this._renderCardHeader(headerImage, headerInfoConfig), React.createElement(Collapsible, {
      collapsed: collapsed,
      animationType: "opacity",
      hideTriggerIcon: true,
      animationSpeed: "fast",
      label: collapsed && this._renderExpandButton(),
      handleClick: onChangeHandler
    }, children));
  };

  return CardCollapsible;
}(Component);

CardCollapsible.defaultProps = {
  collapsed: true,
  headerInfo: {
    displayWhenCollapsed: [],
    displayWhenExpanded: []
  },
  showCloseButton: false,
  hasBoxShadowWhenExpanded: false
};
CardCollapsible.displayName = 'CardCollapsible';
export default CardCollapsible;